@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-# PyTils - simple processing for russian strings
+# pytils - simple processing for russian strings
 # Copyright (C) 2006-2007  Yury Yurevich
 #
-# http://gorod-omsk.ru/blog/pythy/projects/pytils/
+# http://www.pyobject.ru/pythy/projects/pytils/
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,5 +17,5 @@
 Pytils templatetags for Django web-framework
 """
 
-__id__ = __revision__ = "$Id: __init__.py 63 2007-01-02 09:22:16Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/trunk/pytils/pytils/templatetags/__init__.py $"
+__id__ = __revision__ = "$Id: __init__.py 102 2007-07-12 12:33:36Z the.pythy $"
+__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/templatetags/__init__.py $"
