@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-# PyTils - simple processing for russian strings
+# pytils - simple processing for russian strings
 # Copyright (C) 2006-2007  Yury Yurevich
 #
-# http://gorod-omsk.ru/blog/pythy/projects/pytils/
+# http://www.pyobject.ru/projects/pytils/
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,8 +17,8 @@
 Unit-tests for pytils.numeral
 """
 
-__id__ = __revision__ = "$Id: test_numeral.py 63 2007-01-02 09:22:16Z the.pythy $"
-__url__ = "$URL: https://pythy.googlecode.com/svn/trunk/pytils/pytils/test/test_numeral.py $"
+__id__ = __revision__ = "$Id: test_numeral.py 102 2007-07-12 12:33:36Z the.pythy $"
+__url__ = "$URL: https://pythy.googlecode.com/svn/tags/pytils/0_2_2/pytils/test/test_numeral.py $"
 
 import unittest
 import pytils
@@ -67,9 +67,61 @@ class ChoosePluralTestCase(unittest.TestCase):
                           -25, u"any,bene,raba")
 
     def testChoosePluralVariantsInStr(self):
+        """
+        Tests new-style variants
+        """
         self.assertEquals(
             pytils.numeral.choose_plural(1,u"гвоздь,гвоздя, гвоздей"),
             u"гвоздь")
+        self.assertEquals(
+            pytils.numeral.choose_plural(5,u"гвоздь, гвоздя, гвоздей\, шпунтов"),
+            u"гвоздей, шпунтов")
+
+class GetPluralTestCase(unittest.TestCase):
+    """
+    Test case for get_plural
+    """
+    def testGetPlural(self):
+        """
+        Test regular get_plural
+        """
+        self.assertEquals(
+            pytils.numeral.get_plural(1, u"комментарий, комментария, комментариев"),
+            u"1 комментарий")
+        self.assertEquals(
+            pytils.numeral.get_plural(0, u"комментарий, комментария, комментариев"),
+            u"0 комментариев")
+        
+    def testGetPluralAbsence(self):
+        """
+        Test get_plural with absence
+        """
+        self.assertEquals(
+            pytils.numeral.get_plural(1, u"комментарий, комментария, комментариев",
+                                      u"без комментариев"),
+            u"1 комментарий")
+        self.assertEquals(
+            pytils.numeral.get_plural(0, u"комментарий, комментария, комментариев",
+                                      u"без комментариев"),
+            u"без комментариев")
+
+    def testGetPluralLegacy(self):
+        """
+        Test _get_plural_legacy
+        """
+        self.assertEquals(
+            pytils.numeral._get_plural_legacy(1, u"комментарий, комментария, комментариев"),
+            u"1 комментарий")
+        self.assertEquals(
+            pytils.numeral._get_plural_legacy(0, u"комментарий, комментария, комментариев"),
+            u"0 комментариев")
+        self.assertEquals(
+            pytils.numeral._get_plural_legacy(1, u"комментарий, комментария, комментариев, без комментариев"),
+            u"1 комментарий")
+        self.assertEquals(
+            pytils.numeral._get_plural_legacy(0, u"комментарий, комментария, комментариев, без комментариев"),
+            u"без комментариев")
+        
 
 class GetFloatRemainderTestCase(unittest.TestCase):
     """
@@ -305,7 +357,7 @@ class SumStringTestCase(unittest.TestCase):
                                                     self.variants_female),
                           estimated)
 
-    def testSumStringOldStyle(self):
+    def testSumStringOldStyleGender(self):
         """
         Unit-test for sum_string with old-style genders
         """
